==> versions-maven-plugin-2.8.1-sources.jar: org/codehaus/mojo/versions/PluginUpdatesDetails.java <==
package org.codehaus.mojo.versions;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.versioning.ArtifactVersion;
import org.codehaus.mojo.versions.api.ArtifactVersions;
import org.codehaus.mojo.versions.api.UpdateScope;

import java.util.Iterator;
import java.util.Map;
import java.util.Objects;

/**
 * Details of a plugin's updates.
 */
public class PluginUpdatesDetails
{
    private final ArtifactVersions artifactVersions;

    private final Map dependencyVersions;

    private final boolean includeSnapshots;

    public PluginUpdatesDetails( ArtifactVersions artifactVersions, Map dependencyVersions, boolean includeSnapshots )
    {
        Objects.requireNonNull( artifactVersions );
        Objects.requireNonNull( dependencyVersions );
        this.artifactVersions = artifactVersions;
        this.dependencyVersions = dependencyVersions;
        this.includeSnapshots = includeSnapshots;
    }

    public ArtifactVersions getArtifactVersions()
    {
        return artifactVersions;
    }

    public Map getDependencyVersions()
    {
        return dependencyVersions;
    }

    public boolean isArtifactUpdateAvailable()
    {
        return artifactVersions.getAllUpdates( UpdateScope.ANY, includeSnapshots ).length > 0;
    }

    public boolean isDependencyUpdateAvailable()
    {
        for ( Iterator i = dependencyVersions.values().iterator(); i.hasNext(); )
        {
            ArtifactVersions versions = (ArtifactVersions) i.next();
            ArtifactVersion[] dependencyUpdates = versions.getAllUpdates( UpdateScope.ANY, includeSnapshots );
            if ( dependencyUpdates != null && dependencyUpdates.length > 0 )
            {
                return true;
            }
        }
        return false;
    }

    public boolean isUpdateAvailable()
    {
        return isArtifactUpdateAvailable() || isDependencyUpdateAvailable();
    }
}

==> versions-maven-plugin-2.10.0-sources.jar: org/codehaus/mojo/versions/PluginUpdatesDetails.java <==
package org.codehaus.mojo.versions;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.versioning.ArtifactVersion;
import org.apache.maven.model.Dependency;
import org.codehaus.mojo.versions.api.ArtifactVersions;
import org.codehaus.mojo.versions.api.UpdateScope;

import java.util.Map;
import java.util.Objects;

/**
 * Details of a plugin's updates.
 */
public class PluginUpdatesDetails
{
    private final ArtifactVersions artifactVersions;

    private final Map<Dependency, ArtifactVersions> dependencyVersions;

    private final boolean includeSnapshots;

    public PluginUpdatesDetails( ArtifactVersions artifactVersions, Map<Dependency, ArtifactVersions> dependencyVersions, boolean includeSnapshots )
    {
        Objects.requireNonNull( artifactVersions );
        Objects.requireNonNull( dependencyVersions );
        this.artifactVersions = artifactVersions;
        this.dependencyVersions = dependencyVersions;
        this.includeSnapshots = includeSnapshots;
    }

    public ArtifactVersions getArtifactVersions()
    {
        return artifactVersions;
    }

    public Map<Dependency, ArtifactVersions> getDependencyVersions()
    {
        return dependencyVersions;
    }

    public boolean isArtifactUpdateAvailable()
    {
        return artifactVersions.getAllUpdates( UpdateScope.ANY, includeSnapshots ).length > 0;
    }

    public boolean isDependencyUpdateAvailable()
    {
        for ( ArtifactVersions versions : dependencyVersions.values() )
        {
            ArtifactVersion[] dependencyUpdates = versions.getAllUpdates( UpdateScope.ANY, includeSnapshots );
            if ( dependencyUpdates != null && dependencyUpdates.length > 0 )
            {
                return true;
            }
        }
        return false;
    }

    public boolean isUpdateAvailable()
    {
        return isArtifactUpdateAvailable() || isDependencyUpdateAvailable();
    }
}
